============
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every little bit helps, and credit will always be given.

Get Started!
------------

Types of Contributions
----------------------
You can contribute in many ways:

Report Bugs
~~~~~~~~~~~

Report bugs in the issue section of the repository on GitHub.

If you are reporting a bug, please include:

* Detailed steps to reproduce the bug.
* Any details about your local setup that might be helpful in troubleshooting.

Fix Bugs
~~~~~~~~

Look through the issues for bugs. Anything tagged with "bug" is open to whoever wants to implement it.

Implement Features
~~~~~~~~~~~~~~~~~~

Look through the issues for features. Anything tagged with "feature" is open to whoever wants to implement it.

Write Documentation
~~~~~~~~~~~~~~~~~~~

We could always use more documentation, whether as part of the docs or in docstrings in the code.

Submit Feedback
~~~~~~~~~~~~~~~

The best way to send feedback is to file an issue on GitHub.

If you are proposing a feature:

* Explain in detail how it would work.
* Keep the scope as narrow as possible, to make it easier to implement.

